==> 2.5.2.tar.gz: cloudlog/application/language/chinese_simplified/general_words_lang.php <==
<?php

defined('BASEPATH') OR exit('No direct script access allowed');

$lang['error_no_active_station_profile'] = '注意：你需要设置一个活动的台站地址。';

$lang['notice_turn_the_radio_on'] = '你今天还没有 QSO，是时候打开你的电台了！';

$lang['general_word_important'] = '重要';
$lang['general_word_warning'] = '注意';
$lang['general_word_danger'] = '警告';
$lang['general_word_maintenance'] = '维护';
$lang['general_word_info'] = '消息';
$lang['general_word_choose_file'] = '选择文件';
$lang['general_word_next'] = '后一项';
$lang['general_word_previous'] = '前一项';
$lang['general_word_cancel'] = "取消";
$lang['general_word_ok'] = "确认";
$lang['general_word_attention'] = "注意";
$lang['general_word_enabled'] = "已启用";
$lang['general_word_disabled'] = "已禁用";
$lang['general_word_export'] = "导出";
$lang['general_word_import'] = "导入";
$lang['general_word_count'] = "数量";
$lang['general_word_filtering_on'] = "筛选打开";

$lang['general_word_date'] = '日期';
$lang['general_word_startdate'] = "Start Date";
$lang['general_word_enddate'] = "End Date";
$lang['general_word_time'] = '时间';
$lang['general_word_time_on'] = 'Time on';
$lang['general_word_time_off'] = 'Time off';
$lang['general_word_datetime'] = '日期/时间';
$lang['general_word_none'] = '无';
$lang['general_word_name'] = '名称';
$lang['general_word_location'] = '位置';
$lang['general_word_comment'] = '备注';
$lang['general_word_general'] = '通用';
$lang['general_word_satellite'] = '卫星';
$lang['general_word_satellite_short'] = '卫星';
$lang['general_word_notes'] = '笔记';
$lang['general_word_country'] = 'DXCC 实体';
$lang['general_word_city'] = '城市';

$lang['general_word_total'] = '总计';
$lang['general_word_year'] = '年';
$lang['general_word_month'] = '月';

$lang['general_word_colors'] = "颜色";
$lang['general_word_light'] = "浅色/激光";
$lang['general_word_worked'] = '已通联';
$lang['general_word_worked_not_confirmed'] = "已通联未确认";
$lang['general_word_not_worked'] = "未通联";
$lang['general_word_confirmed'] = '已确认';
$lang['general_word_confirmation'] = "Confirmation";
$lang['general_word_needed'] = '待通联';

$lang['general_word_all'] = '所有';
$lang['general_word_no'] = '否';
$lang['general_word_yes'] = '是';
$lang['general_word_method'] = '方法';

$lang['general_word_sent'] = '已发送';
$lang['general_word_received'] = '已收到';
$lang['general_word_requested'] = '已请求';
$lang['general_word_queued'] = '已排队';
$lang['general_word_table'] = "Table";
$lang['general_word_invalid_ignore'] = '无效(忽略)';
$lang['general_word_qslcard'] = 'QSL 卡片';
$lang['general_word_qslcard_management'] = 'QSL 管理';
$lang['general_word_qslcards'] = 'QSL 卡片';
$lang['general_word_qslcard_direct'] = '直邮';
$lang['general_word_qslcard_bureau'] = '卡片局';
$lang['general_word_qslcard_electronic'] = '电子';
$lang['general_word_qslcard_manager'] = '管理员';
$lang['general_word_qslcard_via'] = '通过';
$lang['general_word_eqslcard'] = '电子 QSL 卡片';
$lang['general_word_eqslcards'] = 'eQSL 卡片';
$lang['general_word_lotw'] = 'Logbook of the World（LoTW）';
$lang['general_word_lotw_short'] = 'LoTW';

$lang['general_word_details'] = '详细';
$lang['general_word_qso_data'] = 'QSO 数据';

$lang['general_edit_qso'] = '编辑 QSO';
$lang['general_mark_qsl_rx_bureau'] = '标记 已收到的QSL (卡片局)';
$lang['general_mark_qsl_rx_direct'] = '标记 已收到的QSL (直邮)';
$lang['general_mark_qsl_rx_electronic'] = '标记 已收到的QSL (电子)';
$lang['general_mark_qsl_tx_bureau'] = '标记 已发送的QSL (卡片局)';
$lang['general_mark_qsl_tx_direct'] = '标记 已发送的QSL (直邮)';
$lang['general_mark_qsl_requested'] = '标记 已请求 QSL Card';
$lang['general_mark_qsl_requested_bureau'] = '标记 已请求 QSL Card (卡片局)';
$lang['general_mark_qsl_requested_direct'] = '标记 已请求 QSL Card (直邮)';
$lang['general_mark_qsl_not_required'] = '标记 不需要 QSL Card';

$lang['general_delete_qso'] = '删除 QSO';
$lang['general_more_qso'] = '更多 QSO';

$lang['general_lookup_qrz'] = '在 QRZ.com 上查询';
$lang['general_lookup_hamqth'] = '在 HamQTH 上查询';

$lang['general_total_distance'] = '总计距离';

// PHP Upload Warning
$lang['gen_max_file_upload_size'] = '最大上传文件大小是';

// Cloudlog Terms
$lang['cloudlog_station_profile'] = '台站地址';

// ham radio terms
$lang['gen_hamradio_cq'] = "CQ";
$lang['gen_hamradio_qso'] = 'QSO';
$lang['gen_hamradio_station'] = '台站';

$lang['gen_hamradio_call'] = '呼号';
$lang['gen_hamradio_callsign'] = '呼号';
$lang['gen_hamradio_prefix'] = "Prefix";
$lang['gen_hamradio_suffix'] = "Suffix";
$lang['gen_hamradio_mode'] = '模式';
$lang['gen_hamradio_de'] = '本台呼号(De)';
$lang['gen_hamradio_dx'] = '对方呼号(Dx)';
$lang['gen_hamradio_rst_sent'] = '发';
$lang['gen_hamradio_rst_rcvd'] = '收';
$lang['gen_hamradio_band'] = '频段';
$lang['gen_hamradio_bandgroup'] = "波段";
$lang['gen_hamradio_band_rx'] = '频段 (RX)';
$lang['gen_hamradio_frequency'] = '频率';
$lang['gen_hamradio_frequency_rx'] = '频率 (RX)';
$lang['gen_hamradio_radio'] = '电台';
$lang['gen_hamradio_rsts'] = '信号报告 (发)';
$lang['gen_hamradio_rstr'] = '信号报告 (收)';
$lang['gen_hamradio_refs'] = 'Refs';
$lang['gen_hamradio_myrefs'] = 'My Refs';
$lang['gen_hamradio_exchange_sent_short'] = '信号交换 (发)';
$lang['gen_hamradio_exchange_rcvd_short'] = '信号交换 (收)';
$lang['gen_hamradio_qsl'] = 'QSL';
$lang['gen_hamradio_qsltype'] = "QSL 类型";
$lang['gen_hamradio_qslvia'] = 'QSL via';
$lang['gen_hamradio_qslmsg'] = 'QSL 信息';
$lang['gen_hamradio_locator'] = '定位器';
$lang['gen_hamradio_transmit_power'] = '发射功率 (W)';
$lang['gen_hamradio_propagation_mode'] = '传播模式';

$lang['gen_hamradio_satellite_name'] = '卫星名称';
$lang['gen_hamradio_satellite_mode'] = '卫星模式';

$lang['gen_hamradio_logbook'] = '日志簿';
$lang['gen_hamradio_award'] = "Award";

$lang['gen_hamradio_zones'] = '分区';
$lang['gen_hamradio_cq_zone'] = 'CQ 分区';
$lang['gen_hamradio_itu_zone'] = 'ITU 分区';
$lang['gen_hamradio_dxcc'] = 'DXCC实体';
$lang['gen_hamradio_deleted_dxcc'] = '删除 DXCC 实体';
$lang['gen_hamradio_continent'] = '大陆';
$lang['gen_hamradio_usa_state'] = '州（美国）';
$lang['gen_hamradio_county_reference'] = '县（美国）';
$lang['gen_hamradio_iota_reference'] = 'IOTA 编号';
$lang['gen_hamradio_sota_reference'] = 'SOTA 编号';
$lang['gen_hamradio_wwff_reference'] = 'WWFF 编号';
$lang['gen_hamradio_pota_reference'] = 'POTA 编号';
$lang['gen_hamradio_dok'] = 'DOK';
$lang['gen_hamradio_state'] = '州';
$lang['gen_hamradio_iota'] = 'IOTA';
$lang['gen_hamradio_sota'] = 'SOTA';
$lang['gen_hamradio_wwff'] = 'WWFF';
$lang['gen_hamradio_pota'] = 'POTA';
$lang['gen_hamradio_gridsquare'] = '网格';
$lang['gen_hamradio_get_gridsquare'] = '获取网格座标';
$lang['gen_hamradio_latitude'] = "纬度";
$lang['gen_hamradio_longitude'] = "经度";
$lang['gen_hamradio_bearing'] = "方位角";
$lang['gen_hamradio_distance'] = '距离';
$lang['gen_hamradio_operator'] = '操作员';

$lang['gen_hamradio_sig'] = 'Sig';
$lang['gen_hamradio_sig_info'] = 'Sig 属性';

// Find your CQ/ITU Zone
$lang['gen_find_zone_cq_part1'] = "如果您不知道自己的 CQ 分区";
$lang['gen_find_zone_itu_part1'] = "如果您不知道自己的 ITU 分区";
$lang['gen_find_zone_part2'] = "点击此处";
$lang['gen_find_zone_part3'] = "来查询！";

// Dashboard Words
$lang['dashboard_you_have_had'] = '今天你有';
$lang['dashboard_qsos_today'] = '个 QSO!';
$lang['dashboard_qso_breakdown'] = 'QSO 分析';
$lang['dashboard_countries_breakdown'] = 'DXCC 实体分析';
$lang['gen_to_date'] = 'To date';

$lang['gen_from_date'] = '起始日期';

$lang['gen_this_qso_was_confirmed_on'] = '该 QSO 确认于';

$lang['error_no_logbook_found'] = '没有找到日志本。您需要在台站日志下添加一个日志本! 在这里添加：';

$lang['copy_to_clipboard'] = '复制到剪贴板';

$lang['africa'] = '非洲';
$lang['antarctica'] = '南极洲';
$lang['asia'] = '亚洲';
$lang['europe'] = '欧洲';
$lang['northamerica'] = '北美洲';
$lang['oceania'] = '大洋洲';
$lang['southamerica'] = '南美洲';

$lang['gen_band_selection'] = '波段选择';
$lang['general_word_today'] = '今天';

$lang['dashboard_php_version_warning'] = 'You need to upgrade your PHP version. Minimum version is 7.4. Your version is';
$lang['dashboard_country_files_warning'] = 'You need to update country files! Go <a href="'.site_url('update').'">here</a> to do it!';
$lang['dashboard_locations_warning'] = 'You have no station locations. Go <a href="'. site_url('station') . '">here</a> to create it!';
$lang['dashboard_logbooks_warning'] = 'You have no station logbook. Go <a href="'. site_url('logbooks') . '">here</a> to create it!';

$lang['hams_at_no_activations_found'] = 'No upcoming activations found. Please check back later.';

==> 2.6.3.tar.gz: cloudlog/application/language/chinese_simplified/general_words_lang.php <==
<?php

defined('BASEPATH') OR exit('No direct script access allowed');

$lang['error_no_active_station_profile'] = '注意：你需要设置一个活动的电台站地址';

$lang['notice_turn_the_radio_on'] = '你今天还没进行QSO，是时候打开你的电台开始通联了！';

$lang['general_word_important'] = '重要';
$lang['general_word_warning'] = '注意';
$lang['general_word_danger'] = '警告';
$lang['general_word_maintenance'] = '维护';
$lang['general_word_info'] = '消息';
$lang['general_word_choose_file'] = '选择文件';
$lang['general_word_next'] = '后一项';
$lang['general_word_previous'] = '前一项';
$lang['general_word_cancel'] = "取消";
$lang['general_word_ok'] = "确认";
$lang['general_word_attention'] = "注意";
$lang['general_word_enabled'] = "已启用";
$lang['general_word_disabled'] = "已禁用";
$lang['general_word_export'] = "导出";
$lang['general_word_import'] = "导入";
$lang['general_word_count'] = "数量";
$lang['general_word_filtering_on'] = "筛选打开";
$lang['general_word_not_display'] = "不显示";
$lang['general_word_icon'] = "图标";
$lang['general_word_never'] = "从不";

$lang['general_word_date'] = '日期';
$lang['general_word_startdate'] = "开始时间";
$lang['general_word_enddate'] = "结束时间";
$lang['general_word_time'] = '时间';
$lang['general_word_time_on'] = '打开时间';
$lang['general_word_time_off'] = '关闭时间';
$lang['general_word_datetime'] = '日期/时间';
$lang['general_word_none'] = '无';
$lang['general_word_name'] = '名称';
$lang['general_word_location'] = '位置';
$lang['general_word_comment'] = '备注';
$lang['general_word_general'] = '通用';
$lang['general_word_satellite'] = '卫星';
$lang['general_word_satellite_short'] = '卫星';
$lang['general_word_notes'] = '笔记';
$lang['general_word_country'] = 'DXCC 实体';
$lang['general_word_city'] = '城市';

$lang['general_word_total'] = '总计';
$lang['general_word_year'] = '年';
$lang['general_word_month'] = '月';
$lang['general_word_day'] = "日";
$lang['general_word_days'] = "天";

$lang['general_word_colors'] = "颜色";
$lang['general_word_light'] = "浅色/高光";
$lang['general_word_worked'] = '已通联';
$lang['general_word_worked_not_confirmed'] = "已通联未确认";
$lang['general_word_not_worked'] = "未通联";
$lang['general_word_confirmed'] = '已确认';
$lang['general_word_confirmation'] = "确认";
$lang['general_word_needed'] = '待通联';

$lang['general_word_all'] = '所有';
$lang['general_word_no'] = '否';
$lang['general_word_yes'] = '是';
$lang['general_word_method'] = '方法';

$lang['general_word_sent'] = '已发送';
$lang['general_word_received'] = '已收到';
$lang['general_word_requested'] = '已请求';
$lang['general_word_queued'] = '已排队';
$lang['general_word_table'] = "Table";
$lang['general_word_invalid_ignore'] = '无效(忽略)';
$lang['general_word_qslcard'] = 'QSL 卡片';
$lang['general_word_qslcard_management'] = 'QSL 管理';
$lang['general_word_qslcards'] = 'QSL 卡片';
$lang['general_word_qslcard_direct'] = '直邮';
$lang['general_word_qslcard_bureau'] = '卡片局';
$lang['general_word_qslcard_electronic'] = '电子';
$lang['general_word_qslcard_manager'] = '管理员';
$lang['general_word_qslcard_via'] = '通过';
$lang['general_word_eqslcard'] = '电子 QSL 卡片';
$lang['general_word_eqslcards'] = 'eQSL 卡片';
$lang['general_word_lotw'] = 'Logbook of the World（LoTW）';
$lang['general_word_lotw_short'] = 'LoTW';

$lang['general_word_details'] = '详细';
$lang['general_word_qso_data'] = 'QSO 数据';

$lang['general_edit_qso'] = '编辑 QSO';
$lang['general_mark_qsl_rx_bureau'] = '标记 已收到的QSL (卡片局)';
$lang['general_mark_qsl_rx_direct'] = '标记 已收到的QSL (直邮)';
$lang['general_mark_qsl_rx_electronic'] = '标记 已收到的QSL (电子)';
$lang['general_mark_qsl_tx_bureau'] = '标记 已发送的QSL (卡片局)';
$lang['general_mark_qsl_tx_direct'] = '标记 已发送的QSL (直邮)';
$lang['general_mark_qsl_requested'] = '标记 已请求 QSL Card';
$lang['general_mark_qsl_requested_bureau'] = '标记 已请求 QSL Card (卡片局)';
$lang['general_mark_qsl_requested_direct'] = '标记 已请求 QSL Card (直邮)';
$lang['general_mark_qsl_not_required'] = '标记 不需要 QSL Card';

$lang['general_delete_qso'] = '删除 QSO';
$lang['general_more_qso'] = '更多 QSO';

$lang['general_lookup_qrz'] = '在 QRZ.com 上查询';
$lang['general_lookup_hamqth'] = '在 HamQTH 上查询';

$lang['general_total_distance'] = '总计距离';

// PHP Upload Warning
$lang['gen_max_file_upload_size'] = '最大上传文件大小是';

// Cloudlog Terms
$lang['cloudlog_station_profile'] = '电台站地址';

// ham radio terms
$lang['gen_hamradio_cq'] = "CQ";
$lang['gen_hamradio_qso'] = 'QSO';
$lang['gen_hamradio_station'] = '电台站';

$lang['gen_hamradio_call'] = '呼号';
$lang['gen_hamradio_callsign'] = '呼号';
$lang['gen_hamradio_prefix'] = "前缀";
$lang['gen_hamradio_suffix'] = "后缀";
$lang['gen_hamradio_mode'] = '模式';
$lang['gen_hamradio_de'] = '本台呼号(De)';
$lang['gen_hamradio_dx'] = '对方呼号(Dx)';
$lang['gen_hamradio_rst_sent'] = 'Sent RST';
$lang['gen_hamradio_rst_rcvd'] = 'Rcvd RST';
$lang['gen_hamradio_band'] = '频段';
$lang['gen_hamradio_bandgroup'] = "波段";
$lang['gen_hamradio_band_rx'] = '频段 (RX)';
$lang['gen_hamradio_frequency'] = '频率';
$lang['gen_hamradio_frequency_rx'] = '频率 (RX)';
$lang['gen_hamradio_radio'] = '电台';
$lang['gen_hamradio_rsts'] = '信号报告 (发)';
$lang['gen_hamradio_rstr'] = '信号报告 (收)';
$lang['gen_hamradio_refs'] = '对方网格';
$lang['gen_hamradio_myrefs'] = '电台网格';
$lang['gen_hamradio_exchange_sent_short'] = '信号交换 (发)';
$lang['gen_hamradio_exchange_rcvd_short'] = '信号交换 (收)';
$lang['gen_hamradio_qsl'] = 'QSL';
$lang['gen_hamradio_qsltype'] = "QSL 类型";
$lang['gen_hamradio_qslvia'] = 'QSL via';
$lang['gen_hamradio_qslmsg'] = 'QSL 信息';
$lang['gen_hamradio_locator'] = '定位地图';
$lang['gen_hamradio_transmit_power'] = '发射功率 (W)';
$lang['gen_hamradio_propagation_mode'] = '传播模式';

$lang['gen_hamradio_satellite_name'] = '卫星名称';
$lang['gen_hamradio_satellite_mode'] = '卫星模式';

$lang['gen_hamradio_logbook'] = '日志簿';
$lang['gen_hamradio_award'] = "奖项";

$lang['gen_hamradio_zones'] = '分区';
$lang['gen_hamradio_cq_zone'] = 'CQ 分区';
$lang['gen_hamradio_itu_zone'] = 'ITU 分区';
$lang['gen_hamradio_dxcc'] = 'DXCC实体';
$lang['gen_hamradio_deleted_dxcc'] = '删除 DXCC 实体';
$lang['gen_hamradio_continent'] = '大陆';
$lang['gen_hamradio_usa_state'] = '州（美国）';
$lang['gen_hamradio_county_reference'] = '县（美国）';
$lang['gen_hamradio_iota_reference'] = 'IOTA 编号';
$lang['gen_hamradio_sota_reference'] = 'SOTA 编号';
$lang['gen_hamradio_wwff_reference'] = 'WWFF 编号';
$lang['gen_hamradio_pota_reference'] = 'POTA 编号';
$lang['gen_hamradio_dok'] = 'DOK';
$lang['gen_hamradio_state'] = '州';
$lang['gen_hamradio_iota'] = 'IOTA';
$lang['gen_hamradio_sota'] = 'SOTA';
$lang['gen_hamradio_wwff'] = 'WWFF';
$lang['gen_hamradio_pota'] = 'POTA';
$lang['gen_hamradio_gridsquare'] = '网格';
$lang['gen_hamradio_get_gridsquare'] = '获取网格座标';
$lang['gen_hamradio_gridsquare_show'] = "显示定位地图";
$lang['gen_hamradio_latitude'] = "纬度";
$lang['gen_hamradio_longitude'] = "经度";
$lang['gen_hamradio_bearing'] = "方位角";
$lang['gen_hamradio_distance'] = '距离';
$lang['gen_hamradio_operator'] = '操作员';

$lang['gen_hamradio_sig'] = 'Sig';
$lang['gen_hamradio_sig_info'] = 'Sig 属性';

// Find your CQ/ITU Zone
$lang['gen_find_zone_cq_part1'] = "如果您不知道自己的 CQ 分区";
$lang['gen_find_zone_itu_part1'] = "如果您不知道自己的 ITU 分区";
$lang['gen_find_zone_part2'] = "点击此处";
$lang['gen_find_zone_part3'] = "来查询";

// Dashboard Words
$lang['dashboard_you_have_had'] = '今天你有';
$lang['dashboard_qsos_today'] = '个 QSO!';
$lang['dashboard_qso_breakdown'] = 'QSO 分析';
$lang['dashboard_countries_breakdown'] = 'DXCC 实体分析';
$lang['gen_to_date'] = 'To date';

$lang['gen_from_date'] = '起始日期';

$lang['gen_this_qso_was_confirmed_on'] = '该 QSO 确认于';

$lang['error_no_logbook_found'] = '没有找到日志本。您需要在电台站日志下添加一个日志本! 在这里添加：';

$lang['copy_to_clipboard'] = '复制到剪贴板';

$lang['africa'] = '非洲';
$lang['antarctica'] = '南极洲';
$lang['asia'] = '亚洲';
$lang['europe'] = '欧洲';
$lang['northamerica'] = '北美洲';
$lang['oceania'] = '大洋洲';
$lang['southamerica'] = '南美洲';

$lang['gen_band_selection'] = '波段选择';
$lang['general_word_today'] = '今天';

$lang['dashboard_php_version_warning'] = '您需要升级您的 PHP 版本。 最低版本为 7.4。 你的版本是';
$lang['dashboard_country_files_warning'] = '您需要更新国家/地区文件！ 请前往<a href="'.site_url('update').'">此处</a>执行此操作！';
$lang['dashboard_locations_warning'] = '您没有电台站位置。 前往<a href="'.site_url('station') .'">此处</a>创建它！';
$lang['dashboard_logbooks_warning'] = '你没有电台日志。 请前往<a href="'.site_url('logbooks') .'">此处</a>创建它！';

$lang['hams_at_no_activations_found'] = '未找到即将进行的激活。 请稍后再回来查看。';

$lang['datatables_language'] = "en-GB";
